pub struct LedCanvas { /* private fields */ }Expand description
The Rust handle for the matrix canvas to draw on.
use pi_led_matrix::{LedMatrix, LedColor};
let matrix = LedMatrix::new(None, None).unwrap();
let mut canvas = matrix.canvas();
canvas.fill(&LedColor { red: 128, green: 128, blue: 128 });Implementations
Sourceimpl LedCanvas
impl LedCanvas
Sourcepub fn canvas_size(&self) -> (i32, i32)
pub fn canvas_size(&self) -> (i32, i32)
Retrieves the width & height of the canvas
Sourcepub fn set(&mut self, x: i32, y: i32, color: &LedColor)
pub fn set(&mut self, x: i32, y: i32, color: &LedColor)
Sets the pixel at the given coordinate to the given color.
Sourcepub fn draw_line(
&mut self,
x0: i32,
y0: i32,
x1: i32,
y1: i32,
color: &LedColor,
)
pub fn draw_line( &mut self, x0: i32, y0: i32, x1: i32, y1: i32, color: &LedColor, )
Draws a straight, one pixel wide line using the C++ library.
Consider using embedded-graphics for more drawing features.
Sourcepub fn draw_circle(&mut self, x: i32, y: i32, radius: u32, color: &LedColor)
pub fn draw_circle(&mut self, x: i32, y: i32, radius: u32, color: &LedColor)
Draws a one pixel wide circle using the C++ library.
Consider using embedded-graphics for more drawing features.
Sourcepub fn draw_text(
&mut self,
font: &LedFont,
text: &str,
x: i32,
y: i32,
color: &LedColor,
kerning_offset: i32,
vertical: bool,
) -> i32
pub fn draw_text( &mut self, font: &LedFont, text: &str, x: i32, y: i32, color: &LedColor, kerning_offset: i32, vertical: bool, ) -> i32
Renders text using the C++ library.
Panics
If the given text fails to convert to a CString. This can
occur when there is a null character mid way in the string.